Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7890)

Unified Diff: chrome/common/extensions/user_script.h

Issue 256022: Loads local resources from current locale subtree if available, if not it fal... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/common/extensions/extension_unittest.cc ('k') | chrome/common/extensions/user_script_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/extensions/user_script.h
===================================================================
--- chrome/common/extensions/user_script.h (revision 28272)
+++ chrome/common/extensions/user_script.h (working copy)
@@ -10,6 +10,7 @@
#include "base/file_path.h"
#include "base/string_piece.h"
+#include "chrome/common/extensions/extension_resource.h"
#include "chrome/common/extensions/url_pattern.h"
#include "googleurl/src/gurl.h"
@@ -34,14 +35,16 @@
// Holds actual script file info.
class File {
public:
- File(const FilePath& path, const GURL& url):
- path_(path),
+ File(const ExtensionResource& resource, const GURL& url):
+ resource_(resource),
url_(url) {
}
File() {}
- const FilePath& path() const { return path_; }
- void set_path(const FilePath& path) { path_ = path; }
+ const ExtensionResource& resource() const { return resource_; }
+ void set_resource(const ExtensionResource& resource) {
+ resource_ = resource;
+ }
const GURL& url() const { return url_; }
void set_url(const GURL& url) { url_ = url; }
@@ -61,14 +64,14 @@
content_.assign(content.begin(), content.end());
}
// Serialization support. The content and path_ member will not be
// serialized!
void Pickle(::Pickle* pickle) const;
void Unpickle(const ::Pickle& pickle, void** iter);
private:
- // Where is the script file lives on the disk.
- FilePath path_;
+ // Where the script file lives on the disk.
+ ExtensionResource resource_;
// The url to this scipt file.
GURL url_;
« no previous file with comments | « chrome/common/extensions/extension_unittest.cc ('k') | chrome/common/extensions/user_script_unittest.cc » ('j') | no next file with comments »
@@ -61,14 +64,14 @@
content_.assign(content.begin(), content.end());
}
- // Serialization support. The content and path_ member will not be
+ // Serialization support. The content and resource_ member will not be
// serialized!
void Pickle(::Pickle* pickle) const;

Powered by Google App Engine
This is Rietveld 408576698